==> tw-server-common-2.4.3.1-20230816.100556-1-sources.jar: com/elitesland/tw/tw5/server/prd/sale/entity/SaleContractTempDO.java <==
package com.elitesland.tw.tw5.server.prd.sale.entity;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.bean.copier.CopyOptions;
import com.elitescloud.cloudt.common.annotation.Comment;
import com.elitescloud.cloudt.common.base.BaseModel;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import org.hibernate.annotations.Where;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Table;
import java.io.Serial;
import java.io.Serializable;


/**
 * 合同模板
 *
 * @author duwh
 * @date 2022/09/27
 */
@Entity(name = "sale_contract_temp")
@Table(name = "sale_contract_temp")
@org.hibernate.annotations.Table(appliesTo = "sale_contract_temp", comment = "合同模板")
@Getter
@Setter
@ToString
@Where(clause = "delete_flag = 0")
public class SaleContractTempDO extends BaseModel implements Serializable {

    @Serial
    private static final long serialVersionUID = -2692682723050235496L;

    /**
     * 类别id
     */
    @Comment("合同类别主键 sale_contract_category.id")
    @Column()
    private Long categoryId;

    /**
     * 标签id
     */
    @Comment("标签主键 待定.id")
    @Column()
    private Long tagId;

    /**
     * 名称
     */
    @Comment("名称")
    @Column()
    private String name;

    /**
     * 编号
     */
    @Comment("编号")
    @Column()
    private String tempNo;

    /**
     * 缩略图
     */
    @Comment("图标")
    @Column()
    private String thumbnail;

    /**
     * 隐藏标志 0：不隐藏，1：隐藏
     */
    @Column(
        name = "hidden_flag",
        columnDefinition = "int(10) default '0' comment '是否隐藏，0：不隐藏，1：隐藏' "
    )
    private Integer hiddenFlag;

    /**
     * 排序
     */
    @Comment("排序")
    @Column()
    private Integer sortNo;


    public SaleContractTempDO() {
    }

    public void copy(SaleContractTempDO source) {
        BeanUtil.copyProperties(source, this, CopyOptions.create().setIgnoreNullValue(true));
    }

}

==> tw-server-common-3.0.1-20230927.093446-1-sources.jar: com/elitesland/tw/tw5/server/prd/sale/entity/SaleContractTempDO.java <==
package com.elitesland.tw.tw5.server.prd.sale.entity;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.bean.copier.CopyOptions;
import com.elitescloud.cloudt.common.annotation.Comment;
import com.elitescloud.boot.model.entity.BaseModel;
import lombok.Getter;
import lombok.Setter;
import lombok.ToString;
import org.hibernate.annotations.Where;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Table;
import java.io.Serial;
import java.io.Serializable;


/**
 * 合同模板
 *
 * @author duwh
 * @date 2022/09/27
 */
@Entity(name = "sale_contract_temp")
@Table(name = "sale_contract_temp")
@org.hibernate.annotations.Table(appliesTo = "sale_contract_temp", comment = "合同模板")
@Getter
@Setter
@ToString
@Where(clause = "delete_flag = 0")
public class SaleContractTempDO extends BaseModel implements Serializable {

    @Serial
    private static final long serialVersionUID = -2692682723050235496L;

    /**
     * 类别id
     */
    @Comment("合同类别主键 sale_contract_category.id")
    @Column()
    private Long categoryId;

    /**
     * 标签id
     */
    @Comment("标签主键 待定.id")
    @Column()
    private Long tagId;

    /**
     * 名称
     */
    @Comment("名称")
    @Column()
    private String name;

    /**
     * 编号
     */
    @Comment("编号")
    @Column()
    private String tempNo;

    /**
     * 缩略图
     */
    @Comment("图标")
    @Column()
    private String thumbnail;

    /**
     * 隐藏标志 0：不隐藏，1：隐藏
     */
    @Column(
        name = "hidden_flag",
        columnDefinition = "int(10) default '0' comment '是否隐藏，0：不隐藏，1：隐藏' "
    )
    private Integer hiddenFlag;

    /**
     * 排序
     */
    @Comment("排序")
    @Column()
    private Integer sortNo;


    public SaleContractTempDO() {
    }

    public void copy(SaleContractTempDO source) {
        BeanUtil.copyProperties(source, this, CopyOptions.create().setIgnoreNullValue(true));
    }

}
